SimpleFeature

Struct SimpleFeature 

pub struct SimpleFeature<X, Y> {
    pub label: f64,
    /* private fields */
}
A feature-like type that doesn’t have a variable first dimension, instead using a constant value

Fields

label: f64

A constant value for the first dimension

Implementations

Source

impl<X, Y> SimpleFeature<X, Y>

pub fn new(label: f64, y: Vec<f64>, z: Vec<f32>) -> Self

pub fn as_view(&self) -> SimpleFeatureView<'_, X, Y>

pub fn into_inner(self) -> (f64, Vec<f64>, Vec<f32>)

pub fn empty(label: f64) -> Self

Create an empty SimpleFeature

pub fn with_capacity(capacity: usize, label: f64) -> Self

Createa a new empty SimpleFeature with pre-allocated capacity

pub fn push<T: CoordinateLike<X> + IntensityMeasurement>( &mut self, pt: &T, time: f64, )

Push a new data point onto the feature and ensure the time ordering invariant is satisfied.

pub fn push_raw(&mut self, _x: f64, y: f64, z: f32)

Push a new data point onto the feature and ensure the time ordering invariant is satisfied.